@@ -1,4 +1,4 @@
-from qtstylish import DemoWidget, ThemeSwitcher
+from qtstylish import DemoWidget, ThemeSwitcher, ModernWindow
 import sys
 from PyQt5 import QtWidgets, QtGui, QtCore
 import os
@@ -8,7 +8,10 @@ if __name__ == '__main__':
 
     dw = DemoWidget()
     dw.setStyle(QtWidgets.QStyleFactory.create("Fusion"))
-    ts = ThemeSwitcher(dw, hot_reload=True)
 
-    ts.resize(1000, 700)
+    ts = ThemeSwitcher(dw, hot_reload=True)
+    mw = ModernWindow(ts)
+    ts.widget_to_style = mw
+    mw.resize(1000, 700)
+    mw.show()
     app.exec_()
